pub enum WeightType {
LogRank,
GehanBreslow,
TaroneWare,
FlemingHarrington(f64),
}Expand description
Weight family for the (weighted) log-rank test.
Variants
LogRank
Unweighted log-rank test (all weights equal to 1).
GehanBreslow
Gehan–Breslow: weight by the total number at risk at each event time.
TaroneWare
Tarone–Ware: weight by the square root of the number at risk.
FlemingHarrington(f64)
Fleming–Harrington: weight by S(t-)^p (pooled KM at previous time).